@@ -66,8 +66,13 @@ class Testing_Launch_v1(unittest.TestCase):
     n_gpus = len(os.environ['CUDA_VISIBLE_DEVICES'].split(','))
     PORT = os.environ.get('PORT', 8888)
 
+    if n_gpus > 1:
+      python_str = f"python -m torch.distributed.launch --nproc_per_node={n_gpus} --master_port={PORT} "
+    else:
+      python_str = "python "
+
     cmd_str = f"""
-        python -m torch.distributed.launch --nproc_per_node={n_gpus} --master_port={PORT} 
+        {python_str}
         tl2/launch/scripts/run_ddp.py
         {get_append_cmd_str(args)}
         """
