@@ -110,7 +110,8 @@ def copy_data(rank,
 
 def moxing_copy_parallel(src_url,
                          dst_url,
-                         create_base_dir=True):
+                         create_base_dir=True,
+                         verbose=True):
   """
   Copy dir. copy xxx/data/ to dst/  (dst/data/)
 
@@ -124,13 +125,15 @@ def moxing_copy_parallel(src_url,
     base_dir = Path(src_url).name
     dst_url = f"{dst_url}/{base_dir}"
 
-  print(f"Copy dir from {src_url} to \n\t{dst_url}")
+  if verbose:
+    print(f"Copy dir from {src_url} to \n\t{dst_url}")
   moxing.file.copy_parallel(src_url=src_url, dst_url=dst_url)
   pass
 
 
 def moxing_copy(src_url,
-                dst_url):
+                dst_url,
+                verbose=True):
   """
   Copy a file. copy xxx/data.txt to dst/data.txt
 
@@ -147,7 +150,8 @@ def moxing_copy(src_url,
     # assert moxing.file.exists(dst_url)
     pass
 
-  print(f"Copy file from {src_url} to \n\t{dst_url}")
+  if verbose:
+    print(f"Copy file from {src_url} to \n\t{dst_url}")
   moxing.file.copy(src_url=src_url, dst_url=dst_url)
   pass
 
