@@ -235,9 +235,9 @@ class TestingUnit(unittest.TestCase):
   def test_resnet(self, gpu='0,1,2,3,4,5,6,7', *tmp, **kwargs):
     """
 
-    export PYTHONPATH=./
+    export PYTHONPATH=./:tl2_lib
     python -c "from tl2_lib.tl2.modelarts.scripts import test_bash; \
-      test_bash.TestingUnit().test_resnet(gpu='2,3,4,5,6,7')"
+      test_bash.TestingUnit().test_resnet(gpu='0')"
 
     """
     import torch
