@@ -1,3 +1,13 @@
+"""
+- AttributeError: module 'backend_interagg' has no attribute 'FigureCanvas'
+
+import matplotlib
+matplotlib.use("Agg")
+# matplotlib.use("TkAgg")
+import numpy as np
+
+"""
+
 import numpy as np
 from matplotlib.ticker import MaxNLocator
 from PIL import Image
@@ -154,6 +164,16 @@ def set_non_gui_backend(plt, ):
     fig = plt.figure()
   except:
     plt.switch_backend('agg')
+    
+    
+def set_gui_backend(plt=None):
+  if plt is None:
+    import matplotlib.pyplot as plt
+    
+  try:
+    fig = plt.figure()
+  except:
+    plt.switch_backend('TkAgg')
 
 
 def ax_legend(ax,
@@ -206,4 +226,20 @@ def get_colors_by_cmap(N_colors,
   colors = cmap(np.linspace(0, 1, N_colors))
   if uint8:
     colors = (colors * 255).astype(np.uint8)
-  return colors
\ No newline at end of file
+  return colors
+
+
+def set_axis_equal(ax,
+                   mode='equal'):
+  """
+  
+  :param mode: equal, square
+  :return:
+  """
+  if not isinstance(ax, list):
+    ax = [ax]
+    
+  for sub_ax in ax:
+    sub_ax.axis(mode)
+    
+  pass
\ No newline at end of file
