@@ -1,6 +1,10 @@
 import numpy as np
 
 
+def np_choice(a, size, replace=False):
+  return np.random.choice(a, size=size, replace=replace)
+
+
 def np_deg2rad(degree):
   rad = np.deg2rad(degree)
   return rad
