@@ -20,7 +20,7 @@ def pil_resize(img_pil, size=()):
   :param size: (w, h)
   :return:
   """
-  img_pil = img_pil.resize(size, Image.LANCZOS)
+  img_pil = img_pil.resize(size, Image.Resampling.LANCZOS)
   return img_pil
 
 
@@ -356,6 +356,22 @@ def pil_rectangle(image,
   return image
 
 
+def add_bbox(image,
+             outline='#ff0000',
+             width=2,
+             clone=True):
+  if clone:
+    image = copy.deepcopy(image)
+    
+  draw = ImageDraw.Draw(image)
+  bbox = ((0, 0), image.size)
+  draw.rectangle(bbox, outline=outline, width=width)
+  return image
+
+
+
+
+
 class Testing_pil_utils(unittest.TestCase):
 
   def test_draw_text_on_rectangle(self, debug=True):
