@@ -121,16 +121,25 @@ def is_distributed():
   distributed = n_gpu > 1
   return distributed
 
+def get_num_gpus_by_env():
+  gpus = os.environ["CUDA_VISIBLE_DEVICES"].split(',')
+  return len(gpus)
 
 def get_world_size():
   return d2_comm.get_world_size()
 
 
-def ddp_init(seed=0):
-  """
-  use config_cfgnode
+def ddp_init(seed=0,
+             timeout=None):
   """
 
+  Args:
+    seed:
+    timeout: datetime.timedelta(days=1)
+
+  Returns:
+
+  """
   rank = parser_local_rank()
   distributed = is_distributed()
 
@@ -138,7 +147,13 @@ def ddp_init(seed=0):
   torch.cuda.set_device(rank)
 
   if distributed:
-    torch.distributed.init_process_group(backend="nccl", init_method="env://")
+    if timeout is None:
+      torch.distributed.init_process_group(backend="nccl", init_method="env://")
+    else:
+      torch.distributed.init_process_group(backend="nccl",
+                                           init_method="env://",
+                                           timeout=timeout)
+
     # important: use different random seed for different process
     torch.manual_seed(seed + dist.get_rank())
     torch.cuda.set_device(rank)
