@@ -1,3 +1,5 @@
+import os
+import unittest
 import numpy as np
 from PIL import Image
 import skimage.metrics as sk_metrics
@@ -86,3 +88,57 @@ class LPIPS():
     lpips = self.loss_fn.forward(img0, img1)
     lpips = lpips.view(-1, 1)
     return lpips
+
+
+class Testing_lpips(unittest.TestCase):
+  
+  def test_calc_lpips(self, debug=True):
+    """
+    Usage:
+
+        export CUDA_VISIBLE_DEVICES=0
+        export TIME_STR=0
+        export PYTHONPATH=.:./tl2_lib
+        python -c "from exp.tests.test_styleavatar import Testing_prepare_datasets;\
+          Testing_prepare_datasets().test_detect_yolov7_web(debug=False)" \
+          --tl_opts port 8501
+
+    :return:
+    """
+    if 'CUDA_VISIBLE_DEVICES' not in os.environ:
+      os.environ['CUDA_VISIBLE_DEVICES'] = '0'
+      
+    import torch
+    
+    device = torch.device('cuda')
+    
+    img0 = (torch.rand(1, 3, 256, 256, device=device).cuda() - 0.5) * 2
+    img1 = (torch.rand(1, 3, 256, 256, device=device).cuda() - 0.5) * 2
+    
+    
+    lpips_net = LPIPS()
+    lpips_net.calc_lpips_tensor(img0, img1)
+    pass
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+      
+    
\ No newline at end of file
